@@ -58,6 +58,8 @@ CREATE TABLE IF NOT EXISTS client_allowances (
     max_domains INT DEFAULT 1,
     max_disk_space INT DEFAULT 1000,
     max_email_accounts INT DEFAULT 0,
+    api_enabled BOOLEAN DEFAULT FALSE,
+    api_rate_limit INT DEFAULT 100,
     max_email_storage_mb INT DEFAULT 1000,
     created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
     updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
@@ -639,20 +641,28 @@ CREATE TABLE IF NOT EXISTS wordpress_sites (
     site_path VARCHAR(500) DEFAULT '/home/{user}/public_html',
     admin_email VARCHAR(255),
     admin_username VARCHAR(100),
+    database_name VARCHAR(64) DEFAULT NULL,
     wp_version VARCHAR(20),
     status ENUM('active', 'inactive', 'maintenance') DEFAULT 'active',
     auto_update_core BOOLEAN DEFAULT FALSE,
     auto_update_plugins BOOLEAN DEFAULT FALSE,
     auto_update_themes BOOLEAN DEFAULT FALSE,
     auto_backup_before_update BOOLEAN DEFAULT TRUE,
+    preferred_backup_target_id INT DEFAULT NULL,
+    backup_target_id INT DEFAULT NULL,
     is_staging BOOLEAN DEFAULT FALSE,
     parent_site_id INT,
     created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
     updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
     UNIQUE KEY unique_domain (domain),
     INDEX idx_user (user),
+    INDEX idx_database_name (database_name),
+    INDEX idx_backup_target (backup_target_id),
+    INDEX idx_preferred_backup_target (preferred_backup_target_id),
+    INDEX idx_container (container_name),
     FOREIGN KEY (parent_site_id) REFERENCES wordpress_sites(id) ON DELETE SET NULL,
-    INDEX idx_container (container_name)
+    FOREIGN KEY (preferred_backup_target_id) REFERENCES backup_targets(id) ON DELETE SET NULL,
+    FOREIGN KEY (backup_target_id) REFERENCES backup_targets(id) ON DELETE SET NULL
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
 
 -- Recommended plugins catalog
@@ -972,10 +982,7 @@ CREATE TABLE IF NOT EXISTS api_tokens (
     INDEX idx_expires (expires_at)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
 
--- Add API permissions to existing client_allowances table
-ALTER TABLE client_allowances 
-ADD COLUMN IF NOT EXISTS api_enabled BOOLEAN DEFAULT FALSE AFTER max_email_accounts,
-ADD COLUMN IF NOT EXISTS api_rate_limit INT DEFAULT 100 AFTER api_enabled;
+-- Note: API columns are now included in initial client_allowances table definition
 
 -- Note: API system tables created successfully
 
