@@ -453,7 +453,7 @@ class usermgmt {
             shell_exec("/usr/bin/chmod 755 \"$userfiles_dir\"");
         }
         
-        shell_exec("/usr/bin/echo $username:$password|/usr/sbin/chpasswd");
+        shell_exec("/usr/bin/echo " . escapeshellarg("$username:$password") . "|/usr/sbin/chpasswd");
         
         // Store the password in our database for MySQL authentication
         $this->storeUserPassword($username, $password);
@@ -553,7 +553,7 @@ class usermgmt {
         }
         
         // Change system password
-        shell_exec("/usr/bin/echo $username:$new_password|/usr/sbin/chpasswd");
+        shell_exec("/usr/bin/echo " . escapeshellarg("$username:$new_password") . "|/usr/sbin/chpasswd");
         
         // Update stored password in database
         $this->storeUserPassword($username, $new_password);
